#-----------------------------------------------------------------------------
# Project    : Tutoriels - Conception de circuits intégrés numériques
#-----------------------------------------------------------------------------
# File       : sim.tcl
# Authors    : Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
# Lab        : GRM - Polytechnique Montréal
# Date       : <2019-07-24 Wed>
#-----------------------------------------------------------------------------
# Description: Script pour les simulations du compteur BCD avec Modelsim
# HOW-TO     : source setup.csh && cd simulation/
#            : (CLI) > vsim -c -do ${SCRIPTS_DIR}/sim.tcl
#            : (GUI) > vsim -do ${SCRIPTS_DIR}/sim.tcl
#-----------------------------------------------------------------------------
package require Tcl 8.5

if { ![info exist ::env(PROJECT_HOME)] } {
    error "ERREUR: Configurer l'environnement (source setup.csh) avant d'utiliser ce script"
}

#-----------------------------------------------------------------------------
# CONFIG
#-----------------------------------------------------------------------------
set DO_BEH  0;  # Simulation du modèle comportemental
set DO_SYN  0;  # Smulation de la netlist post-synthèse
set DO_PNR  1;  # Simulation de la netlist post-implémentation
set DO_RUN  1;  # 0=Compilation; 1=Compilation + Simulation
set DO_WAVE 0;  # Chargement des chronogrammes
set DO_VCD  1;  # Enregistrement de l'activité dans un fichier vcd

set top   compteur
set tb    ${top}_tb
set dut   dut
set work  work
set lib   gpdk45
set srcD  $::env(PROJECT_HOME)/sources

if { $DO_BEH } { set workD $::env(SIM_DIR)/beh }
if { $DO_SYN } { set workD $::env(SIM_DIR)/syn }
if { $DO_PNR } { set workD $::env(SIM_DIR)/pnr }

set log  ${workD}/${top}.log
set wlf  ${workD}/${top}.wlf
set vcd  ${workD}/${top}.vcd
set wave ${workD}/${top}.wave.do

if { $DO_SYN } { set net $::env(SYN_NET_DIR)/${top}.syn }
if { $DO_PNR } { set net $::env(PNR_NET_DIR)/${top}.pnr }

#-----------------------------------------------------------------------------
# COMPILATION & SIMULATION
#-----------------------------------------------------------------------------

# Create simulation directory if it does not exists
if { ![file exist $workD] } {
    file mkdir $workD
}

# Copy the default modelsim.ini & Map the technology library
if { ![file exist "./modelsim.ini"] } {
    vmap -c
    vmap $lib $::env(SIMLIB_VER)
}

# Update Work Library
if { [file exist ${workD}/${work}] } {
    vdel -all -lib ${workD}/${work}
}
vlib ${workD}/${work}
vmap ${work} ${workD}/${work}

# Behavioral
if { $DO_BEH } {

    vcom -2008 -work $work ${srcD}/${top}.vhd
    vcom -2008 -work $work ${srcD}/${tb}.vhd
    vsim -t ps -voptargs=+acc -logfile $log -wlf $wlf ${work}.${tb}

# Timing
} elseif { $DO_SYN || $DO_PNR } {

    vlog -work $work ${net}.v
    vcom -2008 -work $work ${srcD}/${tb}.vhd
    vsim -t ps -voptargs=+acc -logfile $log -wlf $wlf -L $lib -sdfmax ${dut}=${net}.sdf ${work}.${tb}
}

#-----------------------------------------------------------------------------
# RUN
#-----------------------------------------------------------------------------
if { $DO_RUN } {

    if { $DO_WAVE } { do $wave }
    if { $DO_VCD }  { vcd file $vcd; vcd add -r /${tb}/${dut}/* }
    run -all
    if { $DO_VCD }  { vcd flush }
}
